sparc64: fix typo in property

There is a typo in a comment that propagated into code:
upa-portis instead of upa-portid

This problem was detected by code inspection.

Fixes: eea9833453bd ("sparc64: broken %tick frequency on spitfire cpus"
Signed-off-by: Pavel Tatashin <pasha.tatashin@oracle.com>
Reported-by: Steven Sistare <steven.sistare@oracle.com>
Reviewed-by: Steven Sistare <steven.sistare@oracle.com>
Signed-off-by: David S. Miller <davem@davemloft.net>
diff --git a/arch/sparc/kernel/time_64.c b/arch/sparc/kernel/time_64.c
index f584c53..564f0e4 100644
--- a/arch/sparc/kernel/time_64.c
+++ b/arch/sparc/kernel/time_64.c
@@ -175,8 +175,8 @@ static unsigned long cpuid_to_freq(phandle node, int cpuid)
 	if (prom_getproperty(node, "device_type", type, sizeof(type)) != -1)
 		is_cpu_node = (strcmp(type, "cpu") == 0);
 
-	/* try upa-portis then cpuid to get cpuid, see prom_64.c */
-	if (is_cpu_node && (prom_getint(node, "upa-portis") == cpuid ||
+	/* try upa-portid then cpuid to get cpuid, see prom_64.c */
+	if (is_cpu_node && (prom_getint(node, "upa-portid") == cpuid ||
 			    prom_getint(node, "cpuid") == cpuid))
 		freq = prom_getintdefault(node, "clock-frequency", 0);
 	if (!freq)